@@ -2,11 +2,12 @@
 
 {-# OPTIONS_HADDOCK -ignore-exports #-}
 
--- | A simple OAuth2 Haskell binding.
---   (This is supposed to be independent with http client.)
+-- | A simple OAuth2 Haskell binding.  (This is supposed to be
+-- independent of the http client used.)
 
 module Network.OAuth.OAuth2.Internal where
 
+import           Control.Applicative  ((<$>), (<*>))
 import           Control.Monad        (mzero)
 import           Data.Aeson
 import qualified Data.ByteString      as BS
@@ -20,7 +21,6 @@ import           Network.HTTP.Types   (renderSimpleQuery)
 --------------------------------------------------
 
 -- | Query Parameter Representation
---
 data OAuth2 = OAuth2 {
       oauthClientId            :: BS.ByteString
     , oauthClientSecret        :: BS.ByteString
@@ -30,10 +30,10 @@ data OAuth2 = OAuth2 {
     } deriving (Show, Eq)
 
 
--- | The gained Access Token. Use @Data.Aeson.decode@ to decode string to @AccessToken@.
---   The @refresheToken@ is special at some case.
---   e.g. https://developers.google.com/accounts/docs/OAuth2
---
+-- | The gained Access Token. Use @Data.Aeson.decode@ to
+-- decode string to @AccessToken@.  The @refreshToken@ is
+-- special in some cases,
+-- e.g. <https://developers.google.com/accounts/docs/OAuth2>
 data AccessToken = AccessToken {
       accessToken  :: BS.ByteString
     , refreshToken :: Maybe BS.ByteString
@@ -41,8 +41,7 @@ data AccessToken = AccessToken {
     , tokenType    :: Maybe BS.ByteString
     } deriving (Show)
 
--- | Parse JSON data into {AccessToken}
---
+-- | Parse JSON data into 'AccessToken'
 instance FromJSON AccessToken where
     parseJSON (Object o) = AccessToken <$> at <*> rt <*> ei <*> tt where
         at = fmap encodeUtf8 $ o .: "access_token"
@@ -56,7 +55,6 @@ instance FromJSON AccessToken where
 --------------------------------------------------
 
 -- | Is either 'Left' containing an error or 'Right' containg a result
---
 type OAuth2Result a = Either BSL.ByteString a
 
 -- | type synonym of query parameters
@@ -73,9 +71,8 @@ type URI = BS.ByteString
 -- * URLs
 --------------------------------------------------
 
--- | Prepare the authorization URL.
---   Redirect to this URL asking for user interactive authentication.
---
+-- | Prepare the authorization URL.  Redirect to this URL
+-- asking for user interactive authentication.
 authorizationUrl :: OAuth2 -> URI
 authorizationUrl oa = oauthOAuthorizeEndpoint oa `appendQueryParam` queryStr
   where queryStr = transform' [ ("client_id", Just $ oauthClientId oa)
@@ -83,13 +80,14 @@ authorizationUrl oa = oauthOAuthorizeEndpoint oa `appendQueryParam` queryStr
                               , ("redirect_uri", oauthCallback oa)]
 
 
--- | Prepare URL and the request body query for fetching access token.
---
+-- | Prepare the URL and the request body query for fetching an access token.
 accessTokenUrl :: OAuth2
                   -> BS.ByteString       -- ^ access code gained via authorization URL
                   -> (URI, PostBody)     -- ^ access token request URL plus the request body.
 accessTokenUrl oa code = accessTokenUrl' oa code (Just "authorization_code")
 
+-- | Prepare the URL and the request body query for fetching an access token, with
+-- optional grant type.
 accessTokenUrl' ::  OAuth2
                     -> BS.ByteString          -- ^ access code gained via authorization URL
                     -> Maybe BS.ByteString    -- ^ Grant Type
@@ -102,9 +100,8 @@ accessTokenUrl' oa code gt = (uri, body)
                           , ("redirect_uri", oauthCallback oa)
                           , ("grant_type", gt) ]
 
--- | Using a Refresh Token.
---   obtain a new access token by sending a refresh token to the Authorization server.
---
+-- | Using a Refresh Token.  Obtain a new access token by
+-- sending a refresh token to the Authorization server.
 refreshAccessTokenUrl :: OAuth2
                          -> BS.ByteString    -- ^ refresh token gained via authorization URL
                          -> (URI, PostBody)  -- ^ refresh token request URL plus the request body.
@@ -119,31 +116,23 @@ refreshAccessTokenUrl oa rtoken = (uri, body)
 -- * UTILs
 --------------------------------------------------
 
--- | Append query parameters with '?'
+-- | Append query parameters using `"?"` or `"&"`.
 appendQueryParam :: URI -> QueryParams -> URI
 appendQueryParam uri q = if "?" `BS.isInfixOf` uri
                          then uri `BS.append` "&" `BS.append` renderSimpleQuery False q
                          else uri `BS.append` renderSimpleQuery True q
 
--- | Append query parameters with '&'.
--- appendQueryParam' :: URI -> QueryParams -> URI
--- appendQueryParam' uri q = uri `BS.append` "&" `BS.append` renderSimpleQuery False q
-
-
--- | For GET method API.
+-- | For `GET` method API.
 appendAccessToken :: URI               -- ^ Base URI
                      -> AccessToken    -- ^ Authorized Access Token
                      -> URI            -- ^ Combined Result
 appendAccessToken uri t = appendQueryParam uri (accessTokenToParam t)
 
--- | Create QueryParams with given access token value.
---
---accessTokenToParam :: BS.ByteString -> QueryParams
---accessTokenToParam token = [("access_token", token)]
+-- | Create 'QueryParams' with given access token value.
 accessTokenToParam :: AccessToken -> QueryParams
 accessTokenToParam (AccessToken token _ _ _) = [("access_token", token)]
 
 
--- | lift value in the Maybe and abonda Nothing
+-- | Lift value in the 'Maybe' and abandon 'Nothing'.
 transform' :: [(a, Maybe b)] -> [(a, b)]
 transform' = map (\(a, Just b) -> (a, b)) . filter (isJust . snd)
